@@ -1,7 +1,7 @@
 package Contenticious;
 use Mojo::Base 'Mojolicious';
 
-our $VERSION = '0.35.1';
+our $VERSION = '0.311';
 
 use Contenticious::Content;
 use Carp;
@@ -29,7 +29,7 @@ sub startup {
     $self->pages_dir($config->{pages_dir} // $self->home->rel_dir('pages'));
 
     # dumping needs relative URLs
-    $self->plugin('RelativeUrlFor');
+    $self->plugin(RelativeUrlFor => {replace_url_for => 1});
 
     # add content helper
     $self->helper(contenticious => sub { $self->content });
@@ -38,7 +38,7 @@ sub startup {
     $self->plugin(Charset => {charset => 'utf8'});
 
     # tell the renderer where to find templates
-    $self->renderer->classes(['Contenticious']);
+    $self->renderer->default_template_class('Contenticious');
 
     # perldoc renderer (to display Contenticious.pod for first-time-users)
     $self->plugin('PODRenderer') if $self->config('perldoc');
@@ -54,7 +54,7 @@ sub startup {
         # found matching content node?
         my $content_node = $c->contenticious->find($path);
         unless (defined $content_node) {
-            $c->reply->not_found;
+            $c->render_not_found;
             return;
         }
 
@@ -83,7 +83,7 @@ __DATA__
 @@ content.html.ep
 % layout 'contenticious', title => $content_node->title;
 % if (defined $content_node->html) {
-%== $content_node->html
+%= b($content_node->html)
 % } else {
 %= include 'list', content_node => $content_node
 % }
@@ -92,7 +92,7 @@ __DATA__
 <h1><%= $content_node->title %></h1>
 <ul id="content_list">
 % foreach my $c (@{$content_node->children}) {
-    % my $url = rel_url_for 'content', cpath => $c->path, format => 'html';
+    % my $url = url_for 'content', cpath => $c->path, format => 'html';
     <li><a href="<%= $url %>"><strong><%= $c->title %></strong></a></li>
 % }
 </ul>
@@ -113,7 +113,7 @@ __DATA__
         % foreach my $c (@{$node->children}) {
             % next if $c->name eq 'index';
             % my $class   = $c->name eq $name ? 'active' : '';
-            % my $url = rel_url_for 'content', cpath => $c->path, format => 'html';
+            % my $url = url_for 'content', cpath => $c->path, format => 'html';
         <li class="<%= $class %>">
             <a href="<%= $url %>"><%= $c->navi_name %></a>
         </li>
@@ -138,12 +138,12 @@ __DATA__
     % my $t = join ' - ' => grep { $_ } stash('title'), config('name');
     <title><%= $t || 'contenticious!' %></title>
     <meta http-equiv="content-type" content="text/html; charset=UTF-8">
-    <link rel="stylesheet" type="text/css" href="<%= rel_url_for 'styles.css' %>">
+    <%= stylesheet 'styles.css' %>
 </head>
 <body>
 <div id="top">
     <div id="inner">
-        <p id="name"><a href="<%= rel_url_for 'content', cpath => '' %>">
+        <p id="name"><a href="<%= url_for 'content', cpath => '' %>">
             <%= config('name') // 'contenticious!' %>
         </a></p>
 %= include 'navi', only => 1
